.. _api-ref:

=============
API Reference
=============

.. _evaluation_ref:

Samplers for Evaluation
=======================

Classes
-------
.. currentmodule:: oasis

.. autosummary::
   :toctree: ../generated
   :template: class.rst

   OASISSampler
   ImportanceSampler
   DruckSampler
   PassiveSampler

.. _stratification_ref:

Stratification
==============

Classes
-------
.. currentmodule:: oasis

.. autosummary::
   :toctree: ../generated
   :template: class.rst

   stratification.Strata

Functions
---------
.. currentmodule:: oasis

.. autosummary::
   :toctree: ../generated
   :template: function.rst

   stratification.stratify_by_scores
   stratification.stratify_by_features
   stratification.auto_stratify
